@@ -192,6 +192,9 @@ censReg <- function( formula, left = 0, right = Inf,
          ... )
    }
 
+   # return mean values of the explanatory variables
+   result$xMean <- colMeans( xMat )
+   
    # save and return the call
    result$call <- match.call()
 
@@ -210,6 +213,10 @@ censReg <- function( formula, left = 0, right = Inf,
    # return starting values
    result$start <- start
 
+   # censoring points
+   result$left <- left
+   result$right <- right
+
    class( result ) <- c( "censReg", class( result ) )
    return( result )
 }
