@@ -20,6 +20,8 @@ vcov( estResult )
 vcov( estResult, logSigma = FALSE )
 coef( summary( estResult ) )
 coef( summary( estResult ), logSigma = FALSE )
+margEff( estResult )
+summary( margEff( estResult ) )
 logLik( estResult )
 extractAIC( estResult )
 formula( estResult )
@@ -36,6 +38,8 @@ waldtest( estResult, . ~ . - age, vcov = sandwich( estResult ) )
 estResultBhhh <- censReg( affairsFormula, data = Affairs, method = "BHHH" )
 print.default( estResultBhhh )
 print( estResultBhhh )
+margEff( estResultBhhh, returnJacobian = TRUE )
+summary( margEff( estResultBhhh ) )
 maxLik:::summary.maxLik( estResultBhhh )
 summary( estResultBhhh )
 all.equal( -crossprod( estfun( estResultBhhh ) ), 
@@ -46,6 +50,8 @@ all.equal( sandwich( estResultBhhh ), vcov( estResultBhhh ) )
 estResultBfgs <- censReg( affairsFormula, data = Affairs, method = "BFGS" )
 print.default( estResultBfgs )
 print( estResultBfgs )
+margEff( estResultBfgs, calcVCov = FALSE )
+summary( margEff( estResultBfgs ) )
 maxLik:::summary.maxLik( estResultBfgs )
 summary( estResultBfgs )
 
@@ -53,6 +59,8 @@ summary( estResultBfgs )
 estResultNm <- censReg( affairsFormula, data = Affairs, method = "NM" )
 print.default( estResultNm )
 print( estResultNm )
+margEff( estResultNm )
+summary( margEff( estResultNm ) )
 maxLik:::summary.maxLik( estResultNm )
 summary( estResultNm )
 
@@ -60,6 +68,8 @@ summary( estResultNm )
 estResultSann <- censReg( affairsFormula, data = Affairs, method = "SANN" )
 print.default( estResultSann )
 print( estResultSann )
+margEff( estResultSann )
+summary( margEff( estResultSann ) )
 maxLik:::summary.maxLik( estResultSann )
 summary( estResultSann )
 
@@ -68,6 +78,8 @@ estResultStart <- censReg( affairsFormula, data = Affairs,
    start = c( 8.17, -0.18, 0.55, -1.69, 0.33, -2.3, 2.13 ) )
 print.default( estResultStart )
 print( estResultStart )
+margEff( estResultStart )
+summary( margEff( estResultStart, calcVCov = FALSE, returnJacobian = TRUE ) )
 maxLik:::summary.maxLik( estResultStart )
 summary( estResultStart )
 logLik( estResultStart )
@@ -79,6 +91,8 @@ estResultAdd <- censReg( affairsAdd ~ age + yearsmarried + religiousness +
    occupation + rating, data = Affairs, left = 5 )
 print.default( estResultAdd )
 print( estResultAdd )
+margEff( estResultAdd )
+summary( margEff( estResultAdd, returnJacobian = TRUE ) )
 maxLik:::summary.maxLik( estResultAdd )
 summary( estResultAdd )
 coef( estResultAdd )
@@ -94,6 +108,8 @@ estResultNeg <- censReg( affairsNeg ~ age + yearsmarried + religiousness +
    occupation + rating, data = Affairs, left = -Inf, right = 0 )
 print.default( estResultNeg )
 print( estResultNeg )
+margEff( estResultNeg, calcVCov = FALSE, returnJacobian = TRUE )
+summary( margEff( estResultNeg ) )
 maxLik:::summary.maxLik( estResultNeg )
 summary( estResultNeg )
 coef( estResultNeg )
@@ -110,6 +126,8 @@ estResultAddNeg <- censReg( affairsAddNeg ~ age + yearsmarried + religiousness +
    occupation + rating, data = Affairs, left = -Inf, right = -5 )
 print.default( estResultAddNeg )
 print( estResultAddNeg )
+margEff( estResultAddNeg )
+summary( margEff( estResultAddNeg, calcVCov = FALSE ) )
 maxLik:::summary.maxLik( estResultAddNeg )
 summary( estResultAddNeg )
 coef( estResultAddNeg )
@@ -123,6 +141,8 @@ extractAIC( estResultAddNeg )
 estResultBoth <- censReg( affairsFormula, data = Affairs, right = 4 )
 print.default( estResultBoth )
 print( estResultBoth )
+margEff( estResultBoth )
+summary( margEff( estResultBoth ) )
 maxLik:::summary.maxLik( estResultBoth )
 summary( estResultBoth )
 print( summary( estResultBoth ), logSigma = FALSE )
@@ -152,6 +172,8 @@ print( estResultEmpty )
 summary( estResultEmpty )
 coef( estResultEmpty )
 vcov( estResultEmpty )
+margEff( estResultEmpty )
+summary( margEff( estResultEmpty ) )
 formula( estResultEmpty )
 model.frame( estResultEmpty )
 estfun( estResultEmpty )[ 20 * c(1:26), ]
